==> owncloud-9.0.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/zh_TW.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "無法存取儲存空間",
    "Storage invalid" : "無效的儲存空間",
    "Unknown error" : "未知的錯誤",
    "Unable to set upload directory." : "無法設定上傳目錄",
    "Invalid Token" : "無效的 token",
    "No file was uploaded. Unknown error" : "沒有檔案被上傳，原因未知",
    "There is no error, the file uploaded with success" : "一切都順利，檔案上傳成功",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 參數的設定：",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "The uploaded file was only partially uploaded" : "只有檔案的一部分被上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Failed to write to disk" : "寫入硬碟失敗",
    "Not enough storage available" : "儲存空間不足",
    "The target folder has been moved or deleted." : "目標資料夾已經被搬移或刪除",
    "Upload failed. Could not find uploaded file" : "上傳失敗，找不到上傳的檔案",
    "Upload failed. Could not get file info." : "上傳失敗，無法取得檔案資訊",
    "Invalid directory." : "無效的資料夾",
    "Files" : "檔案",
    "All files" : "所有檔案",
    "Favorites" : "最愛",
    "Home" : "家目錄",
    "Close" : " 關閉",
    "Upload cancelled." : "上傳已取消",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
    "Total file size {size1} exceeds upload limit {size2}" : "檔案大小總和 {size1} 超過上傳限制 {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，你正要上傳 {size1} 可是只剩下 {size2}",
    "Could not get result from server." : "無法從伺服器取回結果",
    "File upload is in progress. Leaving the page now will cancel the upload." : "檔案上傳中，離開此頁面將會取消上傳",
    "Actions" : "動作",
    "Download" : "下載",
    "Rename" : "重新命名",
    "Delete" : "刪除",
    "Disconnect storage" : "斷開儲存空間連接",
    "Unshare" : "取消分享",
    "Details" : "詳細資料",
    "Select" : "選擇",
    "Pending" : "等候中",
    "Unable to determine date" : "無法確定日期",
    "This operation is forbidden" : "此動作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
    "Could not move \"{file}\", target exists" : "無法移動 \"{file}\"，目標已經存在",
    "Could not move \"{file}\"" : "無法移動 \"{file}\"",
    "{newName} already exists" : "{newName} 已經存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "無法命名檔案 \"{fileName}\"，因為此檔案已經不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱 \"{targetName}\" 在這資料夾 \"{dir}\" 已經被使用。請重新選擇不同的名稱",
    "Could not rename \"{fileName}\"" : "無法重新命名 \"{fileName}\"",
    "Could not create file \"{file}\"" : "無法建立檔案 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "無法建立檔案 \"{file}\"，因為此檔案已存在",
    "Could not create folder \"{dir}\"" : "無法建立資料夾 \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾 \"{dir}\"，因為此資料夾已存在",
    "Error deleting file \"{fileName}\"." : "刪除 \"{fileName}\" 出錯",
    "No entries in this folder match '{filter}'" : "在此資料夾中沒有項目與 '{filter}' 相符",
    "Name" : "名稱",
    "Size" : "大小",
    "Modified" : "修改時間",
    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
    "_%n file_::_%n files_" : ["%n 個檔案"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "You don’t have permission to upload or create files here" : "您沒有權限在這裡上傳或建立檔案",
    "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
    "New" : "新增",
    "\"{name}\" is an invalid file name." : "{name} 是無效的檔名",
    "File name cannot be empty." : "檔名不能為空",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的儲存空間已滿，沒有辦法再更新或是同步檔案！",
    "Your storage is full, files can not be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的儲存空間快要滿了 ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的儲存空間快要滿了 ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["符合「{filter}」"],
    "Path" : "路徑",
    "_%n byte_::_%n bytes_" : ["%n 位元組"],
    "Favorited" : "已加入最愛",
    "Favorite" : "我的最愛",
    "Folder" : "資料夾",
    "New folder" : "新資料夾",
    "{newname} already exists" : "{newname} 已經存在",
    "Upload" : "上傳",
    "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
    "A new file or folder has been <strong>created</strong>" : "新的檔案或目錄已被 <strong>建立</strong>",
    "A file or folder has been <strong>changed</strong>" : "檔案或目錄已被 <strong>變更</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "僅顯示<strong>已加星號的檔案</strong>的動態通知<em>（僅限訊息串）</em>",
    "A file or folder has been <strong>deleted</strong>" : "檔案或目錄已被 <strong>刪除</strong>",
    "A file or folder has been <strong>restored</strong>" : "檔案或目錄已被 <strong>恢復</strong>",
    "You created %1$s" : "您建立了 %1$s",
    "%2$s created %1$s" : "%2$s 已建立 %1$s",
    "%1$s was created in a public folder" : "%1$s 已建立於公開的目錄",
    "You changed %1$s" : "您變更了 %1$s",
    "%2$s changed %1$s" : "%2$s 已變更了 %1$s",
    "You deleted %1$s" : "您刪除了 %1$s",
    "%2$s deleted %1$s" : "%2$s 已刪除 %1$s",
    "You restored %1$s" : "您還原了 %1$s",
    "%2$s restored %1$s" : "%2$s 還原了 %1$s",
    "Changed by %2$s" : "由 %2$s 改動",
    "Deleted by %2$s" : "由 %2$s 刪除",
    "Restored by %2$s" : "由 %2$s 還原",
    "Upload (max. %s)" : "上傳（至多 %s）",
    "File handling" : "檔案處理",
    "Maximum upload size" : "上傳限制",
    "max. possible: " : "最大允許：",
    "Save" : "儲存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "如果使用 PHP-FPM ，此設定值需要5分鐘左右才會生效。",
    "Missing permissions to edit from here." : "您沒有在此編輯的權限",
    "Settings" : "設定",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "使用這個地址<a href=\"%s\" target=\"_blank\">來透過 WebDAV 存取檔案</a>",
    "Cancel upload" : "取消上傳",
    "No files in here" : "沒有任何檔案",
    "Upload some content or sync with your devices!" : "在您的裝置中同步或上傳一些內容",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Select all" : "全選",
    "Upload too large" : "上傳過大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制",
    "No favorites" : "沒有最愛",
    "Files and folders you mark as favorite will show up here" : "您標記為最愛的檔案與資料夾將會顯示在這裡",
    "Text file" : "文字檔",
    "New text file.txt" : "新文字檔.txt",
    "Changed by %2$s" : "由 %2$s 改動",
    "Deleted by %2$s" : "由 %2$s 刪除",
    "Restored by %2$s" : "由 %2$s 還原",
    "You changed %1$s" : "您變更了 %1$s",
    "You created %1$s" : "您建立了 %1$s",
    "You deleted %1$s" : "您刪除了 %1$s",
    "You restored %1$s" : "您還原了 %1$s"
},
"nplurals=1; plural=0;");

==> owncloud-9.1.3-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/zh_TW.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "無法存取儲存空間",
    "Storage invalid" : "無效的儲存空間",
    "Unknown error" : "未知的錯誤",
    "Unable to set upload directory." : "無法設定上傳目錄",
    "Invalid Token" : "無效的 token",
    "No file was uploaded. Unknown error" : "沒有檔案被上傳，原因未知",
    "There is no error, the file uploaded with success" : "一切都順利，檔案上傳成功",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 參數的設定：",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "The uploaded file was only partially uploaded" : "只有檔案的一部分被上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Failed to write to disk" : "寫入硬碟失敗",
    "Not enough storage available" : "儲存空間不足",
    "The target folder has been moved or deleted." : "目標資料夾已經被搬移或刪除",
    "Upload failed. Could not find uploaded file" : "上傳失敗，找不到上傳的檔案",
    "Upload failed. Could not get file info." : "上傳失敗，無法取得檔案資訊",
    "Invalid directory." : "無效的資料夾",
    "Files" : "檔案",
    "All files" : "所有檔案",
    "Home" : "家目錄",
    "Close" : " 關閉",
    "Favorites" : "最愛",
    "Upload cancelled." : "上傳已取消",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
    "Total file size {size1} exceeds upload limit {size2}" : "檔案大小總和 {size1} 超過上傳限制 {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，你正要上傳 {size1} 可是只剩下 {size2}",
    "Error uploading file \"{fileName}\": {message}" : "上傳檔案 \"{fileName}\" 發生錯誤：{message}",
    "Could not get result from server." : "無法從伺服器取回結果",
    "Uploading..." : "上傳中…",
    "..." : "...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "檔案上傳中，離開此頁面將會取消上傳",
    "Actions" : "動作",
    "Download" : "下載",
    "Rename" : "重新命名",
    "Delete" : "刪除",
    "Disconnect storage" : "斷開儲存空間連接",
    "Unshare" : "取消分享",
    "Details" : "詳細資料",
    "Select" : "選擇",
    "Pending" : "等候中",
    "Unable to determine date" : "無法確定日期",
    "This operation is forbidden" : "此動作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
    "Could not move \"{file}\", target exists" : "無法移動 \"{file}\"，目標已經存在",
    "Could not move \"{file}\"" : "無法移動 \"{file}\"",
    "{newName} already exists" : "{newName} 已經存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "無法命名檔案 \"{fileName}\"，因為此檔案已經不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱 \"{targetName}\" 在這資料夾 \"{dir}\" 已經被使用。請重新選擇不同的名稱",
    "Could not rename \"{fileName}\"" : "無法重新命名 \"{fileName}\"",
    "Could not create file \"{file}\"" : "無法建立檔案 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "無法建立檔案 \"{file}\"，因為此檔案已存在",
    "Could not create folder \"{dir}\"" : "無法建立資料夾 \"{dir}\"",
    "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾 \"{dir}\"，因為此資料夾已存在",
    "Error deleting file \"{fileName}\"." : "刪除 \"{fileName}\" 出錯",
    "No entries in this folder match '{filter}'" : "在此資料夾中沒有項目與 '{filter}' 相符",
    "Name" : "名稱",
    "Size" : "大小",
    "Modified" : "修改時間",
    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
    "_%n file_::_%n files_" : ["%n 個檔案"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "You don’t have permission to upload or create files here" : "您沒有權限在這裡上傳或建立檔案",
    "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
    "New" : "新增",
    "\"{name}\" is an invalid file name." : "{name} 是無效的檔名",
    "File name cannot be empty." : "檔名不能為空",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的儲存空間已滿，沒有辦法再更新或是同步檔案！",
    "Your storage is full, files can not be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的儲存空間快要滿了 ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的儲存空間快要滿了 ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["符合「{filter}」"],
    "Path" : "路徑",
    "_%n byte_::_%n bytes_" : ["%n 位元組"],
    "Favorited" : "已加入最愛",
    "Favorite" : "我的最愛",
    "Folder" : "資料夾",
    "New folder" : "新資料夾",
    "{newname} already exists" : "{newname} 已經存在",
    "Upload" : "上傳",
    "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
    "A new file or folder has been <strong>created</strong>" : "新的檔案或目錄已被 <strong>建立</strong>",
    "A file or folder has been <strong>changed</strong>" : "檔案或目錄已被 <strong>變更</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "僅顯示<strong>已加星號的檔案</strong>的動態通知<em>（僅限訊息串）</em>",
    "A file or folder has been <strong>deleted</strong>" : "檔案或目錄已被 <strong>刪除</strong>",
    "A file or folder has been <strong>restored</strong>" : "檔案或目錄已被 <strong>恢復</strong>",
    "You created %1$s" : "您建立了 %1$s",
    "%2$s created %1$s" : "%2$s 已建立 %1$s",
    "%1$s was created in a public folder" : "%1$s 已建立於公開的目錄",
    "You changed %1$s" : "您變更了 %1$s",
    "%2$s changed %1$s" : "%2$s 已變更了 %1$s",
    "You deleted %1$s" : "您刪除了 %1$s",
    "%2$s deleted %1$s" : "%2$s 已刪除 %1$s",
    "You restored %1$s" : "您還原了 %1$s",
    "%2$s restored %1$s" : "%2$s 還原了 %1$s",
    "Changed by %2$s" : "由 %2$s 改動",
    "Deleted by %2$s" : "由 %2$s 刪除",
    "Restored by %2$s" : "由 %2$s 還原",
    "Upload (max. %s)" : "上傳（至多 %s）",
    "File handling" : "檔案處理",
    "Maximum upload size" : "上傳限制",
    "max. possible: " : "最大允許：",
    "Save" : "儲存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "如果使用 PHP-FPM ，此設定值需要5分鐘左右才會生效。",
    "Missing permissions to edit from here." : "您沒有在此編輯的權限",
    "Settings" : "設定",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "使用這個位址來<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">使用 WebDAV 存取檔案</a>",
    "No files in here" : "沒有任何檔案",
    "Upload some content or sync with your devices!" : "在您的裝置中同步或上傳一些內容",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Select all" : "全選",
    "Upload too large" : "上傳過大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制",
    "No favorites" : "沒有最愛",
    "Files and folders you mark as favorite will show up here" : "您標記為最愛的檔案與資料夾將會顯示在這裡",
    "Text file" : "文字檔",
    "New text file.txt" : "新文字檔.txt"
},
"nplurals=1; plural=0;");
